.. FIGARO documentation master file, created by
   sphinx-quickstart on Sat Jul 15 21:24:28 2023.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

FIGARO - Fast Inference for GW Astronomy, Research & Observations
=================================================================

| This page contains the documentation for FIGARO, along with a brief description of how to use it in your research project. Please refer to the `GitHub repository <https://github.com/sterinaldi/FIGARO>`_ for bug reports (extremely appreciated) or issues.
| If you're curious about the other projects I'm working on or if you want to get in touch with me, feel free to visit `my website <https://sterinaldi.github.io>`_!

.. toctree::
   :maxdepth: 1
   :caption: Contents:

   installation.md
   quickstart.md
   use_mixture.md
   acknowledgment.md
   api
   figaro

Indices and tables
^^^^^^^^^^^^^^^^^^

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
